@@ -1,5 +1,6 @@
 import asyncio
-from typing import Any, Dict, Sequence
+import logging
+from typing import Any, Dict, Optional, Sequence
 
 from signalr_async.client import SignalRClientBase
 
@@ -10,17 +11,38 @@ from .hub import SignalRHub
 from .messages import HubInvocation, HubMessage, HubResult
 
 
-class SignalRClient(SignalRClientBase[Sequence[SignalRHub], HubMessage, HubInvocation]):
+class SignalRClient(SignalRClientBase[HubMessage, HubInvocation]):
+    def __init__(
+        self,
+        base_url: str,
+        hubs: Sequence[SignalRHub],
+        timeout: float = 30,
+        keepalive_interval: float = 15,
+        reconnect_policy: bool = True,
+        logger: Optional[logging.Logger] = None,
+        connection_options: Optional[Dict[str, Any]] = None,
+    ):
+        self._hubs = hubs
+        self._hub_dict = {h.name: h for h in self._hubs}
+        super().__init__(
+            base_url,
+            timeout,
+            keepalive_interval,
+            reconnect_policy,
+            logger,
+            connection_options,
+        )
+        for h in self._hubs:
+            h._set_invoke_manager(self._invoke_manager)._set_logger(self.logger)
+
     def build_connection(
         self,
         base_url: str,
         connection_options: Dict[str, Any],
     ) -> SignalRConnection:
-        # TODO: Fix in base
-        self._hub_dict = {h.name: h for h in self._hub}
         return SignalRConnection(
             base_url=base_url,
-            hub_names=[hub.name for hub in self._hub],
+            hub_names=[hub.name for hub in self._hubs],
             extra_params=connection_options.get("extra_params"),
             extra_headers=connection_options.get("extra_headers"),
             logger=self.logger,
@@ -28,11 +50,11 @@ class SignalRClient(SignalRClientBase[Sequence[SignalRHub], HubMessage, HubInvoc
 
     async def _connection_event(self) -> None:
         if self._connection.connection_id:
-            for hub in self._hub:
+            for hub in self._hubs:
                 asyncio.create_task(hub.on_connect(self._connection.connection_id))
 
     async def _disconnection_event(self) -> None:
-        for hub in self._hub:
+        for hub in self._hubs:
             asyncio.create_task(hub.on_disconnect())
 
     async def _process_message(self, message: HubMessage) -> None:
